@@ -1,24 +1,24 @@
-from datetime import datetime
-import json
-from pathlib import Path
-from time import sleep
-import tkinter as tk
-from tkinter import filedialog
 import ctypes
-import sys
+import json
 import os
-import shutil
-import shlex
 import re
-from threading import Thread
-from itertools import zip_longest
+import shlex
+import shutil
 import subprocess
+import sys
+import tkinter as tk
+from datetime import datetime
+from itertools import zip_longest
 from multiprocessing import shared_memory
+from pathlib import Path
+from threading import Thread
+from time import sleep
+from tkinter import filedialog
 
-
-from .global_val import Global_val
-from .easyrip_log import log, Event as LogEvent
-from .ripper import Ripper
+from . import easyrip_web, global_val
+from .easyrip_config import config
+from .easyrip_log import Event as LogEvent
+from .easyrip_log import log
 from .easyrip_mlang import (
     Global_lang_val,
     Lang_tag,
@@ -26,17 +26,15 @@ from .easyrip_mlang import (
     gettext,
     translate_subtitles,
 )
-from . import easyrip_web
-from .easyrip_config import config
+from .ripper import Ripper
+
+__all__ = ["init", "run_command"]
 
 
-__all__ = ["init", "run_command", "log", "Ripper"]
-
-
-PROJECT_NAME = Global_val.PROJECT_NAME
-__version__ = PROJECT_VERSION = Global_val.PROJECT_VERSION
-PROJECT_TITLE = Global_val.PROJECT_TITLE
-PROJECT_URL = Global_val.PROJECT_URL
+PROJECT_NAME = global_val.PROJECT_NAME
+__version__ = PROJECT_VERSION = global_val.PROJECT_VERSION
+PROJECT_TITLE = global_val.PROJECT_TITLE
+PROJECT_URL = global_val.PROJECT_URL
 
 
 def change_title(title: str):
@@ -99,7 +97,7 @@ def check_env():
 
         if config.get_user_profile("check_dependent"):
             _url = "https://ffmpeg.org/download.html"
-            for _name in {"FFmpeg", "FFprobe"}:
+            for _name in ("FFmpeg", "FFprobe"):
                 if not shutil.which(_name):
                     print()
                     log.error(
@@ -186,7 +184,7 @@ def check_env():
                 )
 
             _url = "https://mkvtoolnix.download/downloads.html"
-            for _name in {"mkvpropedit", "mkvmerge"}:
+            for _name in ("mkvpropedit", "mkvmerge"):
                 if not shutil.which(_name):
                     print()
                     log.warning("{} not found, download it: {}", _name, _url)
@@ -211,10 +209,10 @@ def check_env():
 
         if config.get_user_profile("check_update"):
             log_new_ver(
-                easyrip_web.get_github_api_ver(Global_val.PROJECT_RELEASE_API),
+                easyrip_web.get_github_api_ver(global_val.PROJECT_RELEASE_API),
                 PROJECT_VERSION,
                 PROJECT_NAME,
-                f"{Global_val.PROJECT_URL} {gettext("or run '{}' when you use pip", 'pip install -U easyrip')}",
+                f"{global_val.PROJECT_URL} {gettext("or run '{}' when you use pip", 'pip install -U easyrip')}",
             )
 
         sys.stdout.flush()
@@ -222,7 +220,7 @@ def check_env():
         change_title(PROJECT_TITLE)
 
     except Exception as e:
-        log.error(f"The def check_env error: {repr(e)} {e}", deep=True)
+        log.error(f"The def check_env error: {e!r} {e}", deep=True)
 
 
 def get_input_prompt(is_color: bool = False) -> str:
@@ -241,10 +239,10 @@ if os.name == "nt":
         log.warning("Windows DPI Aware failed")
 
 
-def file_dialog():
+def file_dialog(initialdir=None):
     tkRoot = tk.Tk()
     tkRoot.withdraw()
-    file_paths = filedialog.askopenfilenames()
+    file_paths = filedialog.askopenfilenames(initialdir=initialdir)
     tkRoot.destroy()
     return file_paths
 
@@ -470,7 +468,7 @@ def run_command(command: list[str] | str) -> bool:
                             Ripper.ripper_list[i1],
                         )
                     except Exception as e:
-                        log.error(f"{repr(e)} {e}", deep=True)
+                        log.error(f"{e!r} {e}", deep=True)
 
         case "run":
             is_run_exit = False
@@ -491,7 +489,7 @@ def run_command(command: list[str] | str) -> bool:
             run_ripper_list(is_run_exit)
 
         case "server":
-            if easyrip_web.http_server.Event.is_run_command[-1]:
+            if easyrip_web.http_server.Event.is_run_command:
                 log.error("Can not start multiple services")
                 return False
 
@@ -622,7 +620,7 @@ def run_command(command: list[str] | str) -> bool:
             shutdown_sec_str: str | None = None
 
             _skip: bool = False
-            for i in range(0, len(cmd_list)):
+            for i in range(len(cmd_list)):
                 if _skip:
                     _skip = False
                     continue
@@ -631,15 +629,20 @@ def run_command(command: list[str] | str) -> bool:
 
                 match cmd_list[i]:
                     case "-i":
-                        if cmd_list[i + 1] == "fd":
-                            if easyrip_web.http_server.Event.is_run_command[-1]:
-                                log.error("Disable the use of 'fd' on the web")
-                                return False
-                            input_pathname_org_list += file_dialog()
-                        else:
-                            input_pathname_org_list += [
-                                s.strip() for s in cmd_list[i + 1].split("::")
-                            ]
+                        match cmd_list[i + 1]:
+                            case "fd" | "cfd" as fd_param:
+                                if easyrip_web.http_server.Event.is_run_command:
+                                    log.error(
+                                        "Disable the use of '{}' on the web", fd_param
+                                    )
+                                    return False
+                                input_pathname_org_list += file_dialog(
+                                    os.getcwd() if fd_param == "cfd" else None
+                                )
+                            case _:
+                                input_pathname_org_list += [
+                                    s.strip() for s in cmd_list[i + 1].split("::")
+                                ]
 
                     case "-o":
                         output_basename = cmd_list[i + 1]
@@ -664,7 +667,7 @@ def run_command(command: list[str] | str) -> bool:
                                     output_dir,
                                 )
                             except Exception as e:
-                                log.error(f"{repr(e)} {e}", deep=True)
+                                log.error(f"{e!r} {e}", deep=True)
                                 return False
 
                     case "-preset" | "-p":
@@ -705,7 +708,7 @@ def run_command(command: list[str] | str) -> bool:
                                 try:
                                     return _time.strftime(s[5:])
                                 except Exception as e:
-                                    log.error(f"{repr(e)} {e}", deep=True)
+                                    log.error(f"{e!r} {e}", deep=True)
                                     return ""
                             case _:
                                 try:
@@ -719,7 +722,7 @@ def run_command(command: list[str] | str) -> bool:
                                     increment = int(d.get("increment", 1))
                                     return str(start + i * increment).zfill(padding)
                                 except Exception as e:
-                                    log.error(f"{repr(e)} {e}", deep=True)
+                                    log.error(f"{e!r} {e}", deep=True)
                                     return ""
 
                     if output_basename is None:
@@ -873,7 +876,7 @@ def init(is_first_run: bool = False):
             log.LogLevel, str(config.get_user_profile("log_write_level"))
         )
     except Exception as e:
-        log.error(f"{repr(e)} {e}", deep=True)
+        log.error(f"{e!r} {e}", deep=True)
 
     if is_first_run:
         # 设置启动目录
@@ -881,7 +884,7 @@ def init(is_first_run: bool = False):
             if _path := str(config.get_user_profile("startup_directory")):
                 os.chdir(_path)
         except Exception as e:
-            log.error(f"{repr(e)} {e}", deep=True)
+            log.error(f"{e!r} {e}", deep=True)
 
     # 获取终端颜色
     log.init()
@@ -896,7 +899,6 @@ def init(is_first_run: bool = False):
 
         def _post_run_event(cmd: str):
             run_command(cmd)
-            easyrip_web.http_server.Event.is_run_command.append(False)
-            easyrip_web.http_server.Event.is_run_command.popleft()
+            easyrip_web.http_server.Event.is_run_command = False
 
         easyrip_web.http_server.Event.post_run_event = _post_run_event
