@@ -1,9 +1,11 @@
-from ..global_val import Global_val
-from .global_lang_val import Global_lang_val
+from .. import global_val
+from .global_lang_val import Global_lang_val, Lang_tag, Lang_tag_language
+
+LANG_TAG = Lang_tag(language=Lang_tag_language.en)
 
 lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     Global_lang_val.Extra_text_index.HELP_DOC: (
-        f"{Global_val.PROJECT_NAME}\nVersion: {Global_val.PROJECT_VERSION}\n{Global_val.PROJECT_URL}\n"
+        f"{global_val.PROJECT_NAME}\nVersion: {global_val.PROJECT_VERSION}\n{global_val.PROJECT_URL}\n"
         "\n"
         "\n"
         "Help:\n"
@@ -103,8 +105,8 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "\n"
         "Easy Rip options:\n"
         "\n"
-        "  -i <string[::string[?string...]...] | 'fd'>\n"
-        "    Input files' pathname or use file dialog\n"
+        "  -i <string[::string[?string...]...] | 'fd' | 'cfd'>\n"
+        "    Input files' pathname or enter 'fd' to use file dialog, 'cfd' to open from the current directory\n"
         "    In some cases, it is allowed to use '?' as a delimiter to input multiple into a ripper, for example, 'preset subset' allows multiple ASS inputs\n"
         "\n"
         "  -o <string>\n"
