@@ -1,9 +1,21 @@
-from ..global_val import Global_val
-from .global_lang_val import Global_lang_val
+from .. import global_val
+from .global_lang_val import (
+    Global_lang_val,
+    Lang_tag,
+    Lang_tag_language,
+    Lang_tag_region,
+    Lang_tag_script,
+)
+
+LANG_TAG = Lang_tag(
+    language=Lang_tag_language.zh,
+    script=Lang_tag_script.Hans,
+    region=Lang_tag_region.CN,
+)
 
 lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     Global_lang_val.Extra_text_index.HELP_DOC: (
-        f"{Global_val.PROJECT_NAME}\n版本: {Global_val.PROJECT_VERSION}\n{Global_val.PROJECT_URL}\n"
+        f"{global_val.PROJECT_NAME}\n版本: {global_val.PROJECT_VERSION}\n{global_val.PROJECT_URL}\n"
         "\n"
         "\n"
         "帮助:\n"
@@ -103,8 +115,8 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "\n"
         "Easy Rip options:\n"
         "\n"
-        "  -i <string[::string[?string...]...] | 'fd'>\n"
-        "    输入文件的路径名或输入'fd'以使用文件对话框\n"
+        "  -i <string[::string[?string...]...] | 'fd' | 'cfd'>\n"
+        "    输入文件的路径名或输入 'fd' 以使用文件对话框，'cfd' 从当前目录打开\n"
         "    部分情况下允许使用 '?' 作为间隔符往一个 ripper 中输入多个，例如 '-preset subset' 允许输入多个 ASS\n"
         "\n"
         "  -o <string>\n"
@@ -282,7 +294,7 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     "Delete the {}th ripper success": "成功删除第 {} 个 ripper",
     "Will shutdown in {}s after run finished": "将在执行结束后的{}秒后关机",
     "Can not start multiple services": "禁止重复启用服务",
-    "Disable the use of 'fd' on the web": "禁止在 web 使用 'fd'",
+    "Disable the use of '{}' on the web": "禁止在 web 使用 '{}'",
     'Illegal char in -o "{}"': '-o "{}" 中有非法字符',
     'The directory "{}" did not exist and was created': '目录 "{}" 不存在，自动创建',
     "Missing '-preset' option, set to default value 'custom'": "缺少 '-preset' 选项，自动设为默认值 'custom'",
@@ -333,14 +345,14 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     "User profile is not found": "用户配置文件不存在",
     "Key '{}' is not found in user profile": "用户配置文件中不存在 {}",
     # config about
-    "Easy Rip's language, support: {}": "Easy Rip 的语言，支持: {}",
+    "Easy Rip's language, support incomplete matching. Support: {}": "Easy Rip 的语言，支持不完整匹配。支持: {}",
     "Auto check the update of Easy Rip": "自动检测 Easy Rip 更新",
     "Auto check the versions of all dependent programs": "自动检测所有依赖的程序的版本",
     "Program startup directory, when the value is empty, starts in the working directory": "程序启动目录，值为空时在工作目录启动",
     "Force change of log file path, when the value is empty, it is the working directory": "强制更改日志文件所在路径，值为空时为工作目录",
     "Do not write to log file": "不写入日志文件",
-    "Logs this level and above will be printed, and if the value is 'none', they will not be printed, support: {}": "此等级及以上的日志会打印到控制台，若值为 'none' 则不打印，支持: {}",
-    "Logs this level and above will be written, and if the value is 'none', they will not be written, support: {}": "此等级及以上的日志会写入日志文件，若值为 'none' 则不写入，支持: {}",
+    "Logs this level and above will be printed, and if the value is '{}', they will not be printed. Support: {}": "此等级及以上的日志会打印到控制台，若值为 '{}' 则不打印。支持: {}",
+    "Logs this level and above will be written, and if the value is '{}', the '{}' only be written when 'server', they will not be written. Support: {}": "此等级及以上的日志会写入日志文件，若值为 '{}' 则不写入，'{}' 仅在 'server' 时写入。支持: {}",
     # 第三方 API
     "Translating into '{target_lang}' using '{api_name}'": "正在使用 '{api_name}' 翻译为 '{target_lang}'",
     # 通用
