@@ -1,10 +1,10 @@
-from dataclasses import dataclass, field
 import enum
-from pathlib import Path
 import re
+from dataclasses import dataclass, field
+from pathlib import Path
 
 from ...easyrip_log import log
-from ..utils import read_text, uuencode_ssa, uudecode_ssa
+from ..utils import read_text, uudecode_ssa, uuencode_ssa
 
 
 class Style_fmt_it(enum.Enum):
@@ -479,9 +479,9 @@ class Events:
                                 or (
                                     k == Event_fmt_it.Effect
                                     and not (
-                                        v.startswith("Banner;")
-                                        or v.startswith("Scroll up;")
-                                        or v.startswith("Scroll down;")
+                                        v.startswith(
+                                            ("Banner;", "Scroll up;", "Scroll down;")
+                                        )
                                     )
                                 )
                             )
@@ -611,12 +611,7 @@ class Ass:
         state: State = State.unknown
         new_unknown_data: Unknown_data | None = None
 
-        for line in read_text(path).splitlines():
-            line = line.strip()
-
-            if not line:
-                continue
-
+        for line in filter(bool, map(str.strip, read_text(path).splitlines())):
             if line.startswith("[") and line.endswith("]"):
                 if new_unknown_data is not None:
                     self.unknown_data.append(new_unknown_data)
