@@ -1,20 +1,20 @@
+import re
 from io import BytesIO
 from pathlib import Path
-import re
 from typing import Iterable
 
-from ...global_val import Global_val
+from ... import global_val
 from ...easyrip_log import log
+from ..utils import get_base62_time
 from .ass import (
     Ass,
+    Attach_type,
+    Attachment_data,
     Event_data,
     Event_type,
     Script_info_data,
-    Attachment_data,
-    Attach_type,
 )
-from .font import Font_type, Font, load_fonts, subset_font, get_font_path_from_registry
-from ..utils import get_base62_time
+from .font import Font, Font_type, get_font_path_from_registry, load_fonts, subset_font
 
 
 def _bold_italic_to_font_type(bold: bool | int, italic: bool | int) -> Font_type:
@@ -227,7 +227,7 @@ def subset(
         # 修改子集化后的字幕
         path_and_sub.script_info.data = [
             Script_info_data(
-                raw_str=f"; ---------- Font Subset by {Global_val.PROJECT_TITLE} ----------"
+                raw_str=f"; ---------- Font Subset by {global_val.PROJECT_TITLE} ----------"
             ),
             *(
                 Script_info_data(raw_str=f'Font Subset Mapping: "{v}{k}"   ->   "{k}"')
@@ -249,7 +249,7 @@ def subset(
                 }"
             ),
             Script_info_data(
-                raw_str=f"; ---------- {'Font Subset End':^{len(Global_val.PROJECT_TITLE) + 20}} ----------"
+                raw_str=f"; ---------- {'Font Subset End':^{len(global_val.PROJECT_TITLE) + 20}} ----------"
             ),
         ] + path_and_sub.script_info.data
         subset_sub_dict[_ass_path_abs] = (output_dir / _ass_path.name, path_and_sub)
